using System;
using System.Text.Json.Serialization;
namespace org.accordproject.patent {
   using org.accordproject.address;
   using org.accordproject.geo;
   using org.accordproject.person;
   using org.accordproject.usa.residency;
   using concerto;
   class PatentAssetIdentifier : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.PatentAssetIdentifier";
      public string assetNumber { get; set; }
      public AssetNumberStatus numberStatus { get; set; }
      public Country assetCountry { get; set; }
   }
   class PatentClassification : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.PatentClassification";
      public string classificationSymbol { get; set; }
      public string classificationDescription { get; set; }
   }
   class Inventor : Person {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.Inventor";
      public Country residentCountry { get; set; }
      public Residency inventorResidency { get; set; }
   }
   class Applicant : Person {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.Applicant";
   }
   class Assignee : Person {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.Assignee";
   }
   enum AssetNumberStatus {
      APP,
      PAT,
      PUB,
      REISS,
      FOR,
   }

   enum ApplicationType {
      PROV,
      NONPROV,
   }

   enum SubjectMatter {
      UTILITY,
      PLANT,
      DESIGN,
   }

   class PatentAsset : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.patent.PatentAsset";
      public PatentAssetIdentifier[] assetIdentifier { get; set; }
      public string title { get; set; }
      public Inventor[] inventorIdentifier { get; set; }
      public Applicant applicantIdentifier { get; set; }
      public Assignee currentAssignee { get; set; }
      public Assignee originalAssignee { get; set; }
      public DateTime priorityDate { get; set; }
      public DateTime filingDate { get; set; }
      public DateTime issueDate { get; set; }
      public DateTime publicationDate { get; set; }
      public PatentClassification[] classifier { get; set; }
      public string attorneyDocketNumber { get; set; }
      public string customerNumber { get; set; }
      public string[] emailAddress { get; set; }
      public ApplicationType applicationType { get; set; }
      public SubjectMatter subjectMatter { get; set; }
      public float numDrawings { get; set; }
      public float pubFigure { get; set; }
      public PatentAsset[] priorApplication { get; set; }
   }
}
